(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     50631,       1122]
NotebookOptionsPosition[     51022,       1112]
NotebookOutlinePosition[     51457,       1131]
CellTagsIndexPosition[     51414,       1128]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Method of Joints\n",
 StyleBox["Modified by: Niemann Pest, Zhelong He, Marek-Jerzy Pindera\n\
University of Virginia, 2017-10-10\nSource Code from Mathematica \
Demonstrations [1]",
  FontFamily->"Arial",
  FontSize->20,
  FontColor->RGBColor[0., 0., 0.]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "8810eafe-be4e-4a21-bea9-b825d3a57b23"],

Cell[TextData[{
 "To demonstrate the essence of method of joint, this modules solves a truss \
problem using the method of joint. Try to solve this problem first by using \
the default settings, then check your process and answers with this module. \n\
1. The start point is to solve the reaction forces, i.e. the external forces \
applied on joint A and E. Choose \[OpenCurlyDoubleQuote]Loaded Truss \
\[CloseCurlyDoubleQuote] for the left menu, and then go through the five drop \
down buttons for the right",
 StyleBox[" ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "menu, i.e. \[OpenCurlyDoubleQuote]Truss\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]FBD\[CloseCurlyDoubleQuote], ",
 Cell[BoxData[
  FormBox["\"\<\!\(
\*SubscriptBox[\(\[CapitalSigma]M\), \(A\)]\)\>", TraditionalForm]]],
 "=0\[CloseCurlyDoubleQuote], ",
 Cell[BoxData[
  FormBox["\"\<\!\(
\*SubscriptBox[\(\[CapitalSigma]F\), \(x\)]\)\>", TraditionalForm]]],
 "=0\[CloseCurlyDoubleQuote], ",
 Cell[BoxData[
  FormBox["\"\<\!\(
\*SubscriptBox[\(\[CapitalSigma]F\), \(y\)]\)\>", TraditionalForm]]],
 "=0\[CloseCurlyDoubleQuote], and \[OpenCurlyDoubleQuote]Solved FBD\
\[CloseCurlyDoubleQuote], to see the whole process and results for the \
determination of external forces.\n2. Choose \[OpenCurlyDoubleQuote]Balances \
at Joints\[CloseCurlyDoubleQuote] for the left menu. Now you will be leaded \
to focus on the equilibrium of joints of A, B, C and D sequentially, by \
choosing the corresponding button under \[OpenCurlyDoubleQuote]Joints\
\[CloseCurlyDoubleQuote] menu. \n3. Now, you can check the box for \
\[OpenCurlyDoubleQuote]Joint Analysis\[CloseCurlyDoubleQuote] menu and once \
again, go through the buttons A, B, C and D under the \
\[OpenCurlyDoubleQuote]Joints\[CloseCurlyDoubleQuote] menu, to see how this \
module solves these unknown member forces by considering joint equilibrium.\n\
4. Finally, by choosing the \[OpenCurlyDoubleQuote]Solved\
\[CloseCurlyDoubleQuote] button under \[OpenCurlyDoubleQuote]Joints\
\[CloseCurlyDoubleQuote] menu, all the member forces are listed with their \
values and colors indicating tension (green) or compression (purple). The \
external reaction forces are indicated by red.  "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angl$$ = 90, $CellContext`FC$$ = 
    1, $CellContext`focus$$ = False, $CellContext`joints$$ = 
    1, $CellContext`opt$$ = 0, $CellContext`steps$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`steps$$], 1, ""}, {
      1 -> " Loaded Truss ", 2 -> " Balances at Joints "}}, {{
       Hold[$CellContext`opt$$], 0, ""}, {
      0 -> "Truss", 1 -> "FBD", 2 -> 
       "\!\(\*SubscriptBox[\(\[CapitalSigma]M\), \(A\)]\)=0", 3 -> Row[{
          Style["", Italic], 
          "\!\(\*SubscriptBox[\(\[CapitalSigma]F\), \(x\)]\)=0"}], 4 -> Row[{
          Style["", Italic], 
          "\!\(\*SubscriptBox[\(\[CapitalSigma]F\), \(y\)]\)=0"}], 5 -> 
       "Solved FBD"}}, {{
       Hold[$CellContext`joints$$], 1, "Joints"}, {
      1 -> " A ", 2 -> " B ", 3 -> " C ", 4 -> " D ", 5 -> " Solved "}}, {{
       Hold[$CellContext`focus$$], False, "Joint Analysis"}, {True, False}}, {{
       Hold[$CellContext`FC$$], 1, "Load"}, 1, 2, 0.1}, {{
       Hold[$CellContext`angl$$], 90, "Angle (\[Phi])"}, 0, 180, 5}, {
      Hold[
       Grid[{{
          Graphics[{
            Thickness[Large], 
            Arrowheads[0.3], 
            Arrow[{{0, 0}, {0, 0.5}}], 
            Text[
             Style["y", Medium, Bold], {0, 0.6}], 
            Arrow[{{0, 0}, {0.5, 0}}], 
            Text[
             Style["x", Medium, Bold], {0.6, 0}]}, ImageSize -> {70, 70}], 
          Manipulate`Place[1], 
          Spacer[10], 
          PaneSelector[{1 -> Manipulate`Place[2], 2 -> Grid[{{
                Manipulate`Place[3], 
                Spacer[10], 
                
                PaneSelector[{
                 1 -> Manipulate`Place[4], 2 -> Manipulate`Place[4], 3 -> 
                  Manipulate`Place[4], 4 -> Manipulate`Place[4]}, 
                 Dynamic[$CellContext`joints$$]]}}]}, 
           Dynamic[$CellContext`steps$$]], 
          Manipulate`Place[5], 
          Manipulate`Place[6]}}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {750., {247., 253.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`steps$23699$$ = False, $CellContext`opt$23700$$ = 
    False, $CellContext`joints$23701$$ = False, $CellContext`focus$23702$$ = 
    False, $CellContext`FC$23703$$ = 0, $CellContext`angl$23704$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`angl$$ = 90, $CellContext`FC$$ = 
        1, $CellContext`focus$$ = False, $CellContext`joints$$ = 
        1, $CellContext`opt$$ = 0, $CellContext`steps$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`steps$$, $CellContext`steps$23699$$, False], 
        Hold[$CellContext`opt$$, $CellContext`opt$23700$$, False], 
        Hold[$CellContext`joints$$, $CellContext`joints$23701$$, False], 
        Hold[$CellContext`focus$$, $CellContext`focus$23702$$, False], 
        Hold[$CellContext`FC$$, $CellContext`FC$23703$$, 0], 
        Hold[$CellContext`angl$$, $CellContext`angl$23704$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`w$, $CellContext`h$, $CellContext`\[Theta]$, \
$CellContext`\[Delta]$, $CellContext`sol$, $CellContext`RAx$, \
$CellContext`RAy$, $CellContext`RE$, $CellContext`F1$, $CellContext`F2$, \
$CellContext`F3$, $CellContext`F4$, $CellContext`F5$, $CellContext`F6$, \
$CellContext`F7$, $CellContext`colC$, $CellContext`colT$, $CellContext`colA$, \
$CellContext`truss$, $CellContext`fbd$, $CellContext`calculatemoment$, \
$CellContext`Xforcebalance$, $CellContext`Yforcebalance$, \
$CellContext`solved$, $CellContext`fullstructure$, \
$CellContext`partialstructure$, $CellContext`jointA$, $CellContext`jointB$, \
$CellContext`jointC$, $CellContext`jointD$, $CellContext`jointssolved$, \
$CellContext`equations$}, $CellContext`w$ = 
         1; $CellContext`h$ = ($CellContext`w$/2) 
          Tan[$CellContext`\[Theta]$]; $CellContext`\[Theta]$ = 
         60 Degree; $CellContext`\[Delta]$ = 
         0.25 $CellContext`h$; $CellContext`sol$ = Quiet[
           Part[
            Solve[
             
             N[{$CellContext`w$ ($CellContext`FC$$ 
                  Sin[$CellContext`angl$$ Degree]) - 
                2 $CellContext`w$ $CellContext`re == 
               0, $CellContext`ray - $CellContext`FC$$ 
                Sin[$CellContext`angl$$ Degree] + $CellContext`re == 
               0, $CellContext`rax - $CellContext`FC$$ 
                Cos[$CellContext`angl$$ Degree] == 
               0, $CellContext`f1 
                 Sin[$CellContext`\[Theta]$] + $CellContext`ray == 
               0, $CellContext`f1 
                 Cos[$CellContext`\[Theta]$] + $CellContext`f2 + \
$CellContext`rax == 
               0, (-$CellContext`f1) 
                 Sin[$CellContext`\[Theta]$] - $CellContext`f3 
                Sin[$CellContext`\[Theta]$] == 
               0, (-$CellContext`f1) 
                 Cos[$CellContext`\[Theta]$] + $CellContext`f3 
                 Cos[$CellContext`\[Theta]$] + $CellContext`f4 == 
               0, $CellContext`f3 
                 Sin[$CellContext`\[Theta]$] + $CellContext`f5 
                 Sin[$CellContext`\[Theta]$] - $CellContext`FC$$ 
                Sin[$CellContext`angl$$ Degree] == 
               0, -$CellContext`f2 - $CellContext`f3 
                Cos[$CellContext`\[Theta]$] - $CellContext`FC$$ 
                Cos[$CellContext`angl$$ Degree] + $CellContext`f5 
                 Cos[$CellContext`\[Theta]$] + $CellContext`f6 == 
               0, (-$CellContext`f5) 
                 Sin[$CellContext`\[Theta]$] - $CellContext`f7 
                Sin[$CellContext`\[Theta]$] == 
               0}], {$CellContext`rax, $CellContext`ray, $CellContext`re, \
$CellContext`f1, $CellContext`f2, $CellContext`f3, $CellContext`f4, \
$CellContext`f5, $CellContext`f6, $CellContext`f7}], 1]]; $CellContext`RE$ = 
         ReplaceAll[$CellContext`re, $CellContext`sol$]; $CellContext`RAx$ = 
         ReplaceAll[$CellContext`rax, $CellContext`sol$]; $CellContext`RAy$ = 
         ReplaceAll[$CellContext`ray, $CellContext`sol$]; $CellContext`F1$ = 
         ReplaceAll[$CellContext`f1, $CellContext`sol$]; $CellContext`F2$ = 
         ReplaceAll[$CellContext`f2, $CellContext`sol$]; $CellContext`F3$ = 
         ReplaceAll[$CellContext`f3, $CellContext`sol$]; $CellContext`F4$ = 
         ReplaceAll[$CellContext`f4, $CellContext`sol$]; $CellContext`F5$ = 
         ReplaceAll[$CellContext`f5, $CellContext`sol$]; $CellContext`F6$ = 
         ReplaceAll[$CellContext`f6, $CellContext`sol$]; $CellContext`F7$ = 
         ReplaceAll[$CellContext`f7, $CellContext`sol$]; $CellContext`colC$ = 
         RGBColor[0.55, 0, 0.55]; $CellContext`colT$ = 
         RGBColor[0, 0.5, 0]; $CellContext`colA$ = 
         RGBColor[0.55, 0, 1]; $CellContext`truss$ = {
           Apply[{
             CapForm["Round"], 
             Thickness[#], #2, 
             
             Line[{{0, 0}, {2 $CellContext`w$, 0}, {
               1.5 $CellContext`w$, $CellContext`h$}, {
               0.5 $CellContext`w$, $CellContext`h$}, {0, 0}}], 
             
             Line[{{0.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 
                0}, {1.5 $CellContext`w$, $CellContext`h$}}]}& , {{
             0.022, Black}, {0.015, 
              GrayLevel[0.6]}}, {1}], {
            GrayLevel[0.7], 
            Polygon[{{-0.07, -0.1}, {0.07, -0.1}, {0.035, 0}, {-0.035, 0}}], 
            Disk[{0, 0}, 0.035], 
            Disk[{2 $CellContext`w$, 0}, 0.035], 
            Disk[{2 $CellContext`w$, -0.05}, 0.05], 
            
            Polygon[{{2 $CellContext`w$ - 0.0345, 0.0045}, {
              2 $CellContext`w$ - 0.044, -0.027}, {
              2 $CellContext`w$ + 0.044, -0.027}, {
              2 $CellContext`w$ + 0.0345, 0.0045}}]}, 
           Line[{{-0.2, -0.1}, {0.2, -0.1}}], 
           
           Line[{{2 $CellContext`w$ - 0.2, -0.1}, {
             2 $CellContext`w$ + 0.2, -0.1}}], Gray, Thin, 
           
           Line[{{{-0.19, -0.1}, {-0.24, -0.15}}, {{-0.14, -0.1}, {-0.19, \
-0.15}}, {{-0.09, -0.1}, {-0.14, -0.15}}, {{-0.04, -0.1}, {-0.09, -0.15}}, {{
            0.19, -0.1}, {0.14, -0.15}}, {{0.14, -0.1}, {0.09, -0.15}}, {{
            0.09, -0.1}, {0.04, -0.15}}, {{0.04, -0.1}, {-0.01, -0.15}}}], 
           
           Line[{{{2 $CellContext`w$ - 0.19, -0.1}, {
              2 $CellContext`w$ - 0.24, -0.15}}, {{
              2 $CellContext`w$ - 0.14, -0.1}, {
              2 $CellContext`w$ - 0.19, -0.15}}, {{
              2 $CellContext`w$ - 0.09, -0.1}, {
              2 $CellContext`w$ - 0.14, -0.15}}, {{
              2 $CellContext`w$ - 0.04, -0.1}, {
              2 $CellContext`w$ - 0.09, -0.15}}, {{
              2 $CellContext`w$ + 0.19, -0.1}, {
              2 $CellContext`w$ + 0.14, -0.15}}, {{
              2 $CellContext`w$ + 0.14, -0.1}, {
              2 $CellContext`w$ + 0.09, -0.15}}, {{
              2 $CellContext`w$ + 0.09, -0.1}, {
              2 $CellContext`w$ + 0.04, -0.15}}, {{
              2 $CellContext`w$ + 0.04, -0.1}, {
              2 $CellContext`w$ - 0.01, -0.15}}}], Black, Thick, {Thin, 
            Line[{{-0.035, 0}, {-0.07, -0.1}, {0.07, -0.1}, {0.035, 0}}], 
            Line[
             Map[{#, 
               Sqrt[0.035^2 - #^2]}& , 
              Range[-0.035, 0.035, 0.001]]], 
            Map[
            Line[{{2 $CellContext`w$ + # 0.0345, 0.006}, {
               2 $CellContext`w$ + # 0.044, -0.027}}]& , {-1, 1}], 
            Line[
             Map[{#, 
               Sqrt[0.035^2 - (# - 2 $CellContext`w$)^2]}& , 
              Range[
              2 $CellContext`w$ - 0.0345, 2 $CellContext`w$ + 0.0345, 
               0.0001]]], 
            Line[
             Map[{#, -Sqrt[0.05^2 - (# - 2 $CellContext`w$)^2] - 0.05}& , 
              Range[
              2 $CellContext`w$ - 0.999 0.05, 2 $CellContext`w$ + 0.05, 
               0.001]]], 
            Line[
             Map[{#, Sqrt[0.05^2 - (# - 2 $CellContext`w$)^2] - 0.05}& , 
              Range[
              2 $CellContext`w$ - 0.9999 0.05, 2 $CellContext`w$ - 0.044, 
               0.0001]]], 
            Line[
             Map[{#, Sqrt[0.05^2 - (# - 2 $CellContext`w$)^2] - 0.05}& , 
              Range[
              2 $CellContext`w$ + 0.044, 2 $CellContext`w$ + 1.019 0.05, 
               0.001]]]}, {Black, 
            Text[
             Style["A", 18, Bold], {-0.09, 0}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.2}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {2.12, 0}]}, {Thick, Dashed, 
            
            Circle[{$CellContext`w$, 0}, 0.1, {
             Pi, Pi + $CellContext`angl$$ Degree}]}, {Blue, 
            
            Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
               0.2 $CellContext`FC$$ 
               Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}}], 
            Text[
             Style[
              Row[{
                $CellContext`var["F", "C", Blue], " = ", 
                NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 
              18], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
              Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}, {0, 1.2}]}, {
            Text[
             Style[
             "Every member has an equal length of w", 
              18], {$CellContext`w$, (-0.9) $CellContext`h$}]}}; \
$CellContext`fbd$ = {{Thick, Dashed, 
            
            Circle[{$CellContext`w$, 0}, 0.1, {
             Pi, Pi + $CellContext`angl$$ Degree}]}, {Red, 
            Arrow[{{(-0.25) $CellContext`h$, 0}, {0, 0}}], 
            Arrow[{{0, (-0.25) $CellContext`h$}, {0, 0}}], 
            Apply[Text[
              Style[
               $CellContext`var["R", 
                Row[{"A, ", 
                  Style[#, Italic]}], Red], 18], #2, #3]& , {{
              "x", {(-0.25) $CellContext`h$, 0}, {1, 0}}, {
              "y", {0, (-0.25) $CellContext`h$}, {0, 1.5}}}, {1}]}, {Red, 
            
            Arrow[{{2 $CellContext`w$, (-0.25) $CellContext`h$}, {
              2 $CellContext`w$, 0}}], 
            Text[
             Style[
              $CellContext`var["R", "E", Red], 18], {
             2 $CellContext`w$, (-0.25) $CellContext`h$}, {0, 1.5}]}, {Blue, 
            
            Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
               0.2 $CellContext`FC$$ 
               Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}}], 
            Text[
             Style[
              Row[{
                $CellContext`var["F", "C", Blue], " = ", 
                NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 
              18], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
              Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}, {0, 1.2}]}, {Black, 
            Text[
             Style["A", 18, Bold], {0, 0.15}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.15}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {
             2, 0.15}]}}; $CellContext`calculatemoment$ = {{Blue, 
            
            Arrow[{{$CellContext`w$, 
               0}, {$CellContext`w$, (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}}], 
            Text[
             Style[
              Row[{
                $CellContext`var["F", "vertical", Blue], " = ", 
                
                NumberForm[$CellContext`FC$$ 
                 Sin[$CellContext`angl$$ Degree], {2, 2}], " kN"}], 18, 
              Blue], {$CellContext`w$, (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}, {0, 1.2}]}, {Red, 
            
            Arrow[{{2 $CellContext`w$, (-0.25) $CellContext`h$}, {
              2 $CellContext`w$, 0}}], 
            Text[
             Style[
              $CellContext`var["R", "E", Red], 18], {
             2 $CellContext`w$, (-0.25) $CellContext`h$}, {0, 1.5}]}, 
           Text[
            Style[
             Column[{
               Row[{"sum of the moments about A: \[Sum] ", 
                 $CellContext`var["M", "A", Black], " = 0 = ", 
                 Style["w ", Italic], 
                 $CellContext`var["F", "C", Blue], " sin \[Phi] - 2 ", 
                 Style["w ", Italic], 
                 $CellContext`var["R", "E", Red]}], 
               Row[{"reaction force E: ", 
                 $CellContext`var["R", "E", Red], " = ", 1/2, 
                 $CellContext`var["F", "C", Blue], " sin \[Phi]"}], 
               Style[
                Row[{
                  $CellContext`var["R", "E", Red], " = ", 
                  NumberForm[$CellContext`RE$, {4, 2}], " kN"}], Red]}, 
              Alignment -> "="], 
             18], {$CellContext`w$, (-0.95) $CellContext`h$}], {Black, 
            Text[
             Style["A", 18, Bold], {0, 0.15}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.15}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {
             2, 0.15}]}}; $CellContext`Xforcebalance$ = {{Thick, Dashed, 
            
            Circle[{$CellContext`w$, 0}, 0.1, {
             Pi, Pi + $CellContext`angl$$ Degree}]}, {Red, 
            Arrow[{{(-0.25) $CellContext`h$, 0}, {0, 0}}], 
            Arrow[{{0, (-0.25) $CellContext`h$}, {0, 0}}], Blue, 
            
            Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
               0.2 $CellContext`FC$$ 
               Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}}], Red, 
            
            Arrow[{{2 $CellContext`w$, (-0.25) $CellContext`h$}, {
              2 $CellContext`w$, 0}}]}, 
           Apply[Text[
             Style[
              $CellContext`var["R", 
               Row[{"A, ", 
                 Style[#, Italic]}], Red], 18], #2, #3]& , {{
             "x", {(-0.25) $CellContext`h$, 0}, {1, 0}}, {
             "y", {0, (-0.25) $CellContext`h$}, {0, 1}}}, {1}], 
           Text[
            Style[
             Row[{
               $CellContext`var["R", "E", Red], " = ", 
               NumberForm[$CellContext`RE$, {2, 2}], " kN"}], 18, Red], {
            2 $CellContext`w$, (-0.25) $CellContext`h$}, {0, 1.5}], 
           Text[
            Style[
             Row[{
               $CellContext`var["F", "C", Blue], " = ", 
               NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 18, 
             Blue], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
             Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
             Sin[$CellContext`angl$$ Degree]}, {0, 1.5}], 
           Text[
            Style[
             Column[{
               Row[{"sum of the ", 
                 Style["x", Italic], " forces: \[Sum] ", 
                 Style[
                  Subscript["F", "x"], Italic], " = ", 
                 $CellContext`var["F", "C", Blue], " cos \[Phi] = ", 
                 $CellContext`var["R", 
                  Row[{"A, ", 
                    Style["x", Italic]}], Red]}], 
               Row[{
                 Style["x", Italic], " component of reaction force A: ", 
                 Style[
                  Row[{
                    $CellContext`var["R", 
                    Row[{"A, ", 
                    Style["x", Italic]}], Red], " = ", 
                    NumberForm[$CellContext`RAx$, {4, 2}], " kN"}], Red]}]}, 
              Alignment -> "="], 
             18], {$CellContext`w$, (-0.9) $CellContext`h$}], {Black, 
            Text[
             Style["A", 18, Bold], {0, 0.15}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.15}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {
             2, 0.15}]}}; $CellContext`Yforcebalance$ = {{Thick, Dashed, 
            
            Circle[{$CellContext`w$, 0}, 0.1, {
             Pi, Pi + $CellContext`angl$$ Degree}]}, Red, 
           Arrow[{{(-0.25) $CellContext`h$, 0}, {0, 0}}], 
           
           Arrow[{{2 $CellContext`w$, (-0.25) $CellContext`h$}, {
             2 $CellContext`w$, 0}}], Blue, 
           
           Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
              0.2 $CellContext`FC$$ 
              Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}}], Red, 
           Arrow[{{0, (-0.25) $CellContext`h$}, {0, 0}}], 
           Text[
            Style[
             Row[{
               $CellContext`var["F", "C", Blue], " = ", 
               NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 18, 
             Blue], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
             Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
             Sin[$CellContext`angl$$ Degree]}, {0, 1.5}], 
           Apply[Text[
             Style[
              $CellContext`var["R", 
               Row[{"A, ", 
                 Style[#, Italic]}], Red], 18], #2, #3]& , {{
             "x", {(-0.25) $CellContext`h$, 0}, {1, 0}}, {
             "y", {0, (-0.25) $CellContext`h$}, {0, 1}}}, {1}], 
           Text[
            Style[
             Row[{
               $CellContext`var["R", "E", Red], " = ", 
               NumberForm[$CellContext`RE$, {2, 2}], " kN"}], 18, Red], {
            2 $CellContext`w$, (-0.25) $CellContext`h$}, {0, 1.5}], 
           Text[
            Style[
             Column[{
               Row[{"sum of the ", 
                 Style["y", Italic], " forces: \[Sum] ", 
                 Style[
                  Subscript["F", "y"], Italic], " = 0 = ", 
                 $CellContext`var["R", 
                  Row[{"A, ", 
                    Style["y", Italic]}], Red], " - ", 
                 $CellContext`var["F", "C", Blue], " sin \[Phi] + ", 
                 $CellContext`var["R", "E", Red]}], 
               Row[{
                 Style["y", Italic], " component of reaction force A: ", 
                 $CellContext`var["R", 
                  Row[{"A, ", 
                    Style["y", Italic]}], Red], " = ", 
                 $CellContext`var["F", "C", Blue], " sin \[Phi] - ", 
                 $CellContext`var["R", "E", Red]}], 
               Style[
                Row[{
                  $CellContext`var["R", 
                   Row[{"A, ", 
                    Style["y", Italic]}], Red], " = ", 
                  NumberForm[$CellContext`RAy$, {4, 2}], " kN"}], Red]}, 
              Alignment -> "="], 18, 
             Black], {$CellContext`w$, (-0.95) $CellContext`h$}], {Black, 
            Text[
             Style["A", 18, Bold], {0, 0.15}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.15}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {2, 0.15}]}}; $CellContext`solved$ = {{
           Thick, Dashed, 
            
            Circle[{$CellContext`w$, 0}, 0.1, {
             Pi, Pi + $CellContext`angl$$ Degree}]}, Red, 
           Arrow[{{(-0.2) Abs[$CellContext`RAx$], 0}, {0, 0}}], 
           Arrow[{{0, (-0.2) Abs[$CellContext`RAy$]}, {0, 0}}], Blue, 
           
           Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
              0.2 $CellContext`FC$$ 
              Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}}], Red, 
           
           Arrow[{{2 $CellContext`w$, (-0.2) $CellContext`RE$}, {
             2 $CellContext`w$, 0}}], 
           Text[
            Style[
             Row[{
               $CellContext`var["F", "C", Blue], " = ", 
               NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 18, 
             Blue], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
             Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
             Sin[$CellContext`angl$$ Degree]}, {0, 1.5}], 
           Text[
            Style[
             Row[{
               $CellContext`var["R", "E", Red], " = ", 
               NumberForm[$CellContext`RE$, {2, 2}], " kN"}], 18, Red], {
            2 $CellContext`w$, (-0.2) $CellContext`RE$}, {0, 1.7}], 
           Apply[Text[
             Style[
              Row[{
                $CellContext`var["R", 
                 Row[{"A, ", 
                   Style[#, Italic]}], Red], " = ", 
                NumberForm[#4, {4, 2}], " kN"}], 18], #2, #3]& , {{
             "x", {(-0.2) Abs[$CellContext`RAx$], 0}, {
              1.2, 0}, $CellContext`RAx$}, {
             "y", {0, (-0.2) $CellContext`RAy$}, {
              0, 1.7}, $CellContext`RAy$}}, {1}], {Black, 
            Text[
             Style["A", 18, Bold], {0, 0.15}], 
            Text[
             Style["B", 18, Bold], {0.4, 0.9}], 
            Text[
             Style["C", 18, Bold], {1, 0.15}], 
            Text[
             Style["D", 18, Bold], {1.6, 0.9}], 
            Text[
             Style["E", 18, Bold], {2, 0.15}]}}; $CellContext`fullstructure$ = {
           Apply[Text[
             Framed[
              Style[
               Subscript[
                Style["F", Italic], #], 18], Background -> White, FrameStyle -> 
              None, FrameMargins -> Tiny], #2]& , {{
             "AB", {$CellContext`w$/4, $CellContext`h$/2}}, {
             "AC", {$CellContext`w$/2, 0}}, {
             "BC", {0.75 $CellContext`w$, $CellContext`h$/2}}, {
             "BD", {$CellContext`w$, $CellContext`h$}}, {
             "CD", {1.25 $CellContext`w$, $CellContext`h$/2}}, {
             "CE", {1.5 $CellContext`w$, 0}}, {
             "DE", {1.75 $CellContext`w$, $CellContext`h$/2}}}, {1}], 
           Apply[Text[
             Framed[
              Style[
               Row[{" ", #, " "}], 15], Background -> White, RoundingRadius -> 
              15], #2]& , {{"A", {0, 0}}, {
             "B", {0.5 $CellContext`w$, $CellContext`h$}}, {
             "C", {$CellContext`w$, 0}}, {
             "D", {1.5 $CellContext`w$, $CellContext`h$}}, {
             "E", {2 $CellContext`w$, 0}}}, {1}], {Red, Dashed, 
            Circle[
             
             Switch[$CellContext`joints$$, 1, {0, 0}, 2, {
              0.5 $CellContext`w$, $CellContext`h$}, 3, {$CellContext`w$, 0}, 
              4, {1.5 $CellContext`w$, $CellContext`h$}, 5, {
              2 $CellContext`w$, 0}], 0.2]}}; $CellContext`partialstructure$ = {
           If[$CellContext`joints$$ == 1, {$CellContext`colT$, 
             
             Arrow[{{0, 0.05 $CellContext`h$}, {$CellContext`w$/
                4, $CellContext`h$/2}}], 
             Arrow[{{0, 0}, {$CellContext`w$/2, 0}}], Red, 
             
             Arrow[{{0, (-0.25) $CellContext`h$}, {
               0, (-0.05) $CellContext`h$}}], 
             Text[
              Style[
               Row[{
                 $CellContext`var["R", "A,y", Red], " = ", 
                 NumberForm[$CellContext`RAy$, {2, 2}], " kN"}], 18], {
              0, (-0.25) $CellContext`h$}, {0, 1.5}], Red, 
             
             Arrow[{{(-0.25) $CellContext`h$, 0}, {(-0.05) $CellContext`h$, 
                0}}], 
             Text[
              Style[
               Row[{
                 $CellContext`var["R", "A,x", Red], " = ", 
                 NumberForm[$CellContext`RAx$, {2, 2}], " kN"}], 
               18], {(-0.25) $CellContext`h$, 0}, {1, 0}]}], 
           If[$CellContext`joints$$ == 2, {$CellContext`colT$, 
             
             Arrow[{0.96 {$CellContext`w$/
                 2, $CellContext`h$}, {$CellContext`w$/4, $CellContext`h$/
                2}}], 
             
             Arrow[{{$CellContext`w$/2, $CellContext`h$}, {
               3 ($CellContext`w$/4), $CellContext`h$/2}}], 
             
             Arrow[{{1.07 ($CellContext`w$/
                 2), $CellContext`h$}, {$CellContext`w$, $CellContext`h$}}]}], 
           If[$CellContext`joints$$ == 3, {$CellContext`colT$, 
             Arrow[{{$CellContext`w$, 0}, {0, 0}}], 
             Arrow[{{$CellContext`w$, 0}, {2 $CellContext`w$, 0}}], 
             
             Arrow[{{$CellContext`w$, 0}, {
               0.5 $CellContext`w$, $CellContext`h$}}], 
             
             Arrow[{{$CellContext`w$, 0}, {
               1.5 $CellContext`w$, $CellContext`h$}}], Blue, 
             
             Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
                0.2 $CellContext`FC$$ 
                Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
                Sin[$CellContext`angl$$ Degree]}}], 
             Text[
              Style[
               Row[{
                 $CellContext`var["F", "C", Blue], " = ", 
                 NumberForm[$CellContext`FC$$, {2, 2}], " kN"}], 
               18], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
               Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}, {0, 1.2}]}], 
           If[$CellContext`joints$$ == 4, {$CellContext`colT$, 
             
             Arrow[{{0.96 1.5 $CellContext`w$, $CellContext`h$}, {
               0.5 $CellContext`w$, $CellContext`h$}}], 
             
             Arrow[{{1.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 
                0}}], 
             
             Arrow[{{1.01 1.5 $CellContext`w$, 0.96 $CellContext`h$}, {
               2 $CellContext`w$, 0}}]}]}; $CellContext`jointA$ = {{
           Thick, Dashed, 
            Circle[{0, 0}, 0.1, {0, $CellContext`\[Theta]$}]}, 
           Text[
            Style[
             Row[{"\[Theta] = ", $CellContext`\[Theta]$}], 17], {0, 
            0}, {-2.2, -1}], 
           Apply[Text[
             Style[
              $CellContext`var["F", #, Black], 18], #2, #3]& , {{
             "AB", {$CellContext`w$/4, $CellContext`h$/2}, {-1.5, -1.5}}, {
             "AC", {$CellContext`w$/2, 0}, {-1.5, 0}}}, {1}], 
           Text[
            Framed[
             Style[" A ", 15, 
              GrayLevel[0.4]], Background -> White, RoundingRadius -> 15], {0,
             0}]}; $CellContext`jointB$ = {{Thick, Dashed, 
            
            Circle[{0.5 $CellContext`w$, $CellContext`h$}, 
             0.1, {-$CellContext`\[Theta]$, 0}]}, 
           Text[
            Style[
             
             Row[{"\[Theta] = ", N[$CellContext`\[Theta]$] (180/Pi), 
               "\[Degree]"}], 18], {
            0.5 $CellContext`w$, $CellContext`h$}, {-2.2, 3}], 
           Text[
            Style[
             Row[{
               $CellContext`var["F", "AB", Black], " = ", 
               NumberForm[$CellContext`F1$, {3, 2}], " kN"}], 18, 
             Black], {$CellContext`w$/4, $CellContext`h$/2}, {0, 1.2}], 
           Apply[Text[
             Style[
              $CellContext`var["F", #, Black], 18], #2, #3]& , {{
             "BC", {3 ($CellContext`w$/4), $CellContext`h$/2}, {0, 1.2}}, {
             "BD", {$CellContext`w$, $CellContext`h$}, {-1.2, 0}}}, {1}], 
           Text[
            Framed[
             Style[" B ", 15, 
              GrayLevel[0.4]], Background -> White, RoundingRadius -> 
             15], {$CellContext`w$/
             2, $CellContext`h$}]}; $CellContext`jointC$ = {{Thick, Dashed, 
            Circle[{$CellContext`w$, 0}, 0.1, {0, $CellContext`\[Theta]$}]}, 
           Text[
            Style[
             
             Row[{"\[Theta] = ", N[$CellContext`\[Theta]$] (180/Pi), 
               "\[Degree]"}], 18], {$CellContext`w$, 0}, {-2, -1}], 
           Apply[Text[
             Style[
              Row[{
                $CellContext`var["F", #, Black], " = ", 
                NumberForm[#2, {3, 2}], " kN"}], 18, Black], #3, #4]& , {{
             "AC", $CellContext`F2$, {0, 0}, {1.2, 0}}, {
             "BC", $CellContext`F3$, {0.5 $CellContext`w$, $CellContext`h$}, {
              1, -1.2}}}, {1}], 
           Apply[Text[
             Style[
              $CellContext`var["F", #, Black], 18], #2, #3]& , {{
             "CD", {1.5 $CellContext`w$, $CellContext`h$}, {-1, -1.2}}, {
             "CE", {2 $CellContext`w$, 0}, {-1, 0}}}, {1}], 
           Text[
            Framed[
             Style[" C ", 15, 
              GrayLevel[0.4]], Background -> White, RoundingRadius -> 
             15], {$CellContext`w$, 0}]}; $CellContext`jointD$ = {{
           Thick, Dashed, 
            
            Circle[{1.5 $CellContext`w$, $CellContext`h$}, 0.1, {
             180 Degree, 180 Degree + $CellContext`\[Theta]$}]}, 
           Text[
            Style[
             
             Row[{"\[Theta] = ", N[$CellContext`\[Theta]$] (180/Pi), 
               "\[Degree]"}], 18], {1.5 $CellContext`w$, $CellContext`h$}, {
            2.2, 2}], 
           Apply[Text[
             Style[
              Row[{
                $CellContext`var["F", #, Black], " = ", 
                NumberForm[#2, {3, 2}], " kN"}], 18, Black], #3, #4]& , {{
             "BD", $CellContext`F4$, {0.5 $CellContext`w$, $CellContext`h$}, {
              1.2, 0}}, {
             "CD", $CellContext`F5$, {$CellContext`w$, 0}, {1, 1.2}}}, {1}], 
           Text[
            Style[
             $CellContext`var["F", "DE", Black], 18], {
            2 $CellContext`w$, 0}, {-1, 1.2}], 
           Text[
            Framed[
             Style[" D ", 15, 
              GrayLevel[0.4]], Background -> White, RoundingRadius -> 15], {
            1.5 $CellContext`w$, $CellContext`h$}]}; \
$CellContext`jointssolved$ = {
           Apply[Flatten[{
              
              If[# < 0, $CellContext`colC$, $CellContext`colT$, \
$CellContext`colB], #3, 
              Text[
               Rotate[
                Style[
                 Row[{
                   Subscript[
                    Style[" F", Italic], #2], " = ", 
                   NumberForm[#, {2, 2}], " "}], 18, Background -> 
                 White], #5], #4]}]& , {{$CellContext`F1$, "AB", 
              Line[{{0, 0}, {0.5 $CellContext`w$, $CellContext`h$}}], {
              0.25 $CellContext`w$, 
               0.5 $CellContext`h$}, $CellContext`\[Theta]$}, \
{$CellContext`F2$, "AC", 
              Line[{{0, 0}, {$CellContext`w$, 0}}], {0.5 $CellContext`w$, 0}, 
              0}, {$CellContext`F3$, "BC", 
              
              Line[{{0.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 
                 0}}], {0.75 $CellContext`w$, 
               0.5 $CellContext`h$}, -$CellContext`\[Theta]$}, \
{$CellContext`F4$, "BD", 
              
              Line[{{0.5 $CellContext`w$, $CellContext`h$}, {
                1.5 $CellContext`w$, $CellContext`h$}}], {$CellContext`w$, \
$CellContext`h$}, 0}, {$CellContext`F5$, "CD", 
              
              Line[{{$CellContext`w$, 0}, {
                1.5 $CellContext`w$, $CellContext`h$}}], {
              1.25 $CellContext`w$, 
               0.5 $CellContext`h$}, $CellContext`\[Theta]$}, \
{$CellContext`F6$, "CE", 
              Line[{{$CellContext`w$, 0}, {2 $CellContext`w$, 0}}], {
              1.5 $CellContext`w$, 0}, 0}, {$CellContext`F7$, "DE", 
              
              Line[{{1.5 $CellContext`w$, $CellContext`h$}, {
                2 $CellContext`w$, 0}}], {
              1.75 $CellContext`w$, 
               0.5 $CellContext`h$}, -$CellContext`\[Theta]$}}, {1}], {{
            Thick, Dashed, 
             
             Circle[{$CellContext`w$, 0}, 0.1, {
              Pi, Pi + $CellContext`angl$$ Degree}]}, Red, 
            Arrow[{{(-0.2) Abs[$CellContext`RAx$], 0}, {0, 0}}], 
            Arrow[{{0, (-0.2) Abs[$CellContext`RAy$]}, {0, 0}}], Blue, 
            
            Arrow[{{$CellContext`w$, 0}, {$CellContext`w$ - 
               0.2 $CellContext`FC$$ 
               Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
               Sin[$CellContext`angl$$ Degree]}}], Red, 
            
            Arrow[{{2 $CellContext`w$, (-0.2) $CellContext`RE$}, {
              2 $CellContext`w$, 0}}], 
            Apply[Text[
              Style[
               Row[{
                 $CellContext`var["R", #, Red], " = ", 
                 NumberForm[
                  N[#2], {3, 2}], " kN"}], 18], #3, #4]& , {{
              "A,x", $CellContext`RAx$, {(-0.2) Abs[$CellContext`RAx$], 0}, {
               1.2, 0}}, {
              "A,y", $CellContext`RAy$, {0, (-0.2) $CellContext`RAy$}, {
               0, 1.5}}, {
              "E", $CellContext`RE$, {
               2 $CellContext`w$, (-0.2) $CellContext`RE$}, {0, 1.5}}}, {1}], 
            Blue, 
            Text[
             Style[
              Row[{
                $CellContext`var["F", "C", Blue], " = ", 
                NumberForm[
                 N[$CellContext`FC$$], {3, 2}], " kN"}], 
              18], {$CellContext`w$ - 0.2 $CellContext`FC$$ 
              Cos[$CellContext`angl$$ Degree], (-0.2) $CellContext`FC$$ 
              Sin[$CellContext`angl$$ Degree]}, {0, 1.5}]}, 
           Text[
            Style[
             Row[{"all ", 
               Style["compression", $CellContext`colC$], " and ", 
               Style["tension", $CellContext`colT$], " forces are in kN"}], 
             17, 
             GrayLevel[
             0.4]], {$CellContext`w$, (-0.86) $CellContext`h$}]}; \
$CellContext`equations$ = Graphics[{
            Text[
             Style[
              Switch[$CellContext`joints$$, 1, 
               Grid[{{
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "y"], Italic], " = 0 = ", 
                    $CellContext`var["R", "A,y", Red], " + ", 
                    $CellContext`var["F", "AB", Black], " sin \[Theta]"}], 
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "x"], Italic], " = 0 = ", 
                    $CellContext`var["R", "A,x", Red], " + ", 
                    $CellContext`var["F", "AB", Black], " cos \[Theta] + ", 
                    $CellContext`var["F", "AC", Black]}]}, {
                  Style[
                   Row[{
                    $CellContext`var["F", "AB", Black], " = ", 
                    NumberForm[$CellContext`F1$, {4, 2}], " kN"}], Black], 
                  Style[
                   Row[{
                    $CellContext`var["F", "AC", Black], " = ", 
                    NumberForm[$CellContext`F2$, {4, 2}], " kN"}], Black]}}, 
                Alignment -> "=", Spacings -> {5, Automatic}], 2, 
               Grid[{{
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "y"], Italic], " = 0 = -", 
                    $CellContext`var["F", "AB", Black], " sin \[Theta] - ", 
                    $CellContext`var["F", "BC", Black], " sin \[Theta]"}], 
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "x"], Italic], " = 0 = -", 
                    $CellContext`var["F", "AB", Black], " cos \[Theta] + ", 
                    $CellContext`var["F", "BC", Black], " cos \[Theta] + ", 
                    $CellContext`var["F", "BD", Black]}]}, {
                  Style[
                   Row[{
                    $CellContext`var["F", "BC", Black], " = ", 
                    NumberForm[$CellContext`F3$, {4, 2}], " kN"}], Black], 
                  Style[
                   Row[{
                    $CellContext`var["F", "BD", Black], " = ", 
                    NumberForm[$CellContext`F4$, {4, 2}], " kN"}], Black]}}, 
                Alignment -> "=", Spacings -> {2, Automatic}], 3, 
               Grid[{{
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "y"], Italic], " = -", 
                    $CellContext`var["F", "C", Blue], " sin \[Phi] + ", 
                    $CellContext`var["F", "BC", Black], " sin \[Theta] + ", 
                    $CellContext`var["F", "CD", Black], " sin \[Theta]"}], 
                  Row[{"\[Sum] ", 
                    Style[
                    Subscript["F", "x"], Italic], " = -", 
                    $CellContext`var["F", "C", Blue], " cos \[Phi] - ", 
                    $CellContext`var["F", "AC", Black], " - ", 
                    $CellContext`var["F", "BC", Black], " cos \[Theta] + ", 
                    $CellContext`var["F", "CD", Black], " cos \[Theta] + ", 
                    $CellContext`var["F", "CE", Black]}]}, {
                  Style[
                   Row[{
                    $CellContext`var["F", "CD", Black], " = ", 
                    NumberForm[$CellContext`F5$, {4, 2}], " kN"}], Black], 
                  Style[
                   Row[{
                    $CellContext`var["F", "CE", Black], " = ", 
                    NumberForm[$CellContext`F6$, {4, 2}], " kN"}], Black]}}, 
                Alignment -> "=", Spacings -> {1, Automatic}], 4, 
               Column[{
                 Row[{"\[Sum] ", 
                   Style[
                    Subscript["F", "y"], Italic], " = 0 = -", 
                   $CellContext`var["F", "CD", Black], " sin \[Theta] - ", 
                   $CellContext`var["F", "DE", Black], " sin \[Theta]"}], 
                 Style[
                  Row[{
                    $CellContext`var["F", "DE", Black], " = ", 
                    NumberForm[$CellContext`F7$, {4, 2}], " kN"}], Black]}, 
                Alignment -> "="]], 17]]}, ImageSize -> {800, 70}]; Column[{
           Graphics[{Thick, 
             Arrowheads[Large], 
             If[
              Or[
               
               And[$CellContext`steps$$ == 
                2, $CellContext`focus$$, $CellContext`joints$$ < 5], 
               And[$CellContext`steps$$ == 1, $CellContext`opt$$ == 0]], {}, {
               EdgeForm[Thick], 
               FaceForm[None], 
               
               Polygon[{{0, 0}, {
                 0.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 
                  0}}], 
               
               Polygon[{{0.5 $CellContext`w$, $CellContext`h$}, {
                 1.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 
                  0}}], 
               
               Polygon[{{1.5 $CellContext`w$, $CellContext`h$}, {
                 2 $CellContext`w$, 0}, {$CellContext`w$, 0}}]}], 
             If[$CellContext`steps$$ == 1, 
              
              Switch[$CellContext`opt$$, 0, $CellContext`truss$, 
               1, $CellContext`fbd$, 2, $CellContext`calculatemoment$, 
               3, $CellContext`Xforcebalance$, 4, $CellContext`Yforcebalance$,
                5, $CellContext`solved$], 
              If[$CellContext`focus$$, {$CellContext`partialstructure$, 
                
                Switch[$CellContext`joints$$, 1, $CellContext`jointA$, 
                 2, $CellContext`jointB$, 3, $CellContext`jointC$, 
                 4, $CellContext`jointD$, 5, $CellContext`jointssolved$]}, 
               
               If[$CellContext`joints$$ == 
                5, $CellContext`jointssolved$, $CellContext`fullstructure$]]], 
             If[
              Or[$CellContext`steps$$ == 1, 
               And[$CellContext`steps$$ == 2, $CellContext`joints$$ == 5]], 
              Map[{
                PointSize[0.015], 
                Point[#], White, 
                PointSize[0.01], 
                Point[#]}& , {{0, 0}, {
                0.5 $CellContext`w$, $CellContext`h$}, {$CellContext`w$, 0}, {
                1.5 $CellContext`w$, $CellContext`h$}, {
                2 $CellContext`w$, 0}}]]}, ImageSize -> {750, 
              If[
               
               And[$CellContext`steps$$ == 
                2, $CellContext`focus$$, $CellContext`joints$$ < 5], 200, 
               500]}, PlotRange -> 
            If[$CellContext`steps$$ == 
              1, {{(-1.5) $CellContext`w$, 2.6 $CellContext`w$}, {
                If[
                 And[$CellContext`steps$$ == 1, 
                  
                  Or[$CellContext`opt$$ == 0, $CellContext`opt$$ == 
                   5]], -$CellContext`h$, (-1.2) $CellContext`h$], 
                1.3 $CellContext`h$}}, 
              
              If[$CellContext`joints$$ == 
               5, {{(-1.5) $CellContext`w$, 
                 2.3 $CellContext`w$}, {(-1.2) $CellContext`h$, 
                 1.1 $CellContext`h$}}, 
               
               If[$CellContext`focus$$, 
                All, {{(-0.21) $CellContext`w$, 
                  2.21 $CellContext`w$}, {(-0.25) $CellContext`h$, 
                  1.27 $CellContext`h$}}]]]], 
           If[
            
            And[$CellContext`steps$$ == 
             2, $CellContext`focus$$, $CellContext`joints$$ < 
             5], $CellContext`equations$, Nothing]}, Spacings -> 2]], 
      "Specifications" :> {{{$CellContext`steps$$, 1, ""}, {
         1 -> " Loaded Truss ", 2 -> " Balances at Joints "}, ControlType -> 
         Setter, ControlPlacement -> 1}, {{$CellContext`opt$$, 0, ""}, {
         0 -> "Truss", 1 -> "FBD", 2 -> 
          "\!\(\*SubscriptBox[\(\[CapitalSigma]M\), \(A\)]\)=0", 3 -> Row[{
             Style["", Italic], 
             "\!\(\*SubscriptBox[\(\[CapitalSigma]F\), \(x\)]\)=0"}], 4 -> 
          Row[{
             Style["", Italic], 
             "\!\(\*SubscriptBox[\(\[CapitalSigma]F\), \(y\)]\)=0"}], 5 -> 
          "Solved FBD"}, ControlType -> PopupMenu, ControlPlacement -> 
         2}, {{$CellContext`joints$$, 1, "Joints"}, {
         1 -> " A ", 2 -> " B ", 3 -> " C ", 4 -> " D ", 5 -> " Solved "}, 
         ControlType -> Setter, ControlPlacement -> 
         3}, {{$CellContext`focus$$, False, "Joint Analysis"}, {True, False}, 
         ControlPlacement -> 4}, {{$CellContext`FC$$, 1, "Load"}, 1, 2, 0.1, 
         Appearance -> "Labeled", ImageSize -> Small, ControlPlacement -> 
         5}, {{$CellContext`angl$$, 90, "Angle (\[Phi])"}, 0, 180, 5, 
         Appearance -> "Labeled", ImageSize -> Small, ControlPlacement -> 6}, 
        Grid[{{
           Graphics[{
             Thickness[Large], 
             Arrowheads[0.3], 
             Arrow[{{0, 0}, {0, 0.5}}], 
             Text[
              Style["y", Medium, Bold], {0, 0.6}], 
             Arrow[{{0, 0}, {0.5, 0}}], 
             Text[
              Style["x", Medium, Bold], {0.6, 0}]}, ImageSize -> {70, 70}], 
           Manipulate`Place[1], 
           Spacer[10], 
           PaneSelector[{1 -> Manipulate`Place[2], 2 -> Grid[{{
                 Manipulate`Place[3], 
                 Spacer[10], 
                 
                 PaneSelector[{
                  1 -> Manipulate`Place[4], 2 -> Manipulate`Place[4], 3 -> 
                   Manipulate`Place[4], 4 -> Manipulate`Place[4]}, 
                  Dynamic[$CellContext`joints$$]]}}]}, 
            Dynamic[$CellContext`steps$$]], 
           Manipulate`Place[5], 
           Manipulate`Place[6]}}]}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1033., {317., 323.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`var[
         Pattern[$CellContext`c1, 
          Blank[]], 
         Pattern[$CellContext`c2, 
          Blank[]], 
         Pattern[$CellContext`col, 
          Blank[]]] := Style[
         Subscript[
          Style[$CellContext`c1, Italic], $CellContext`c2], $CellContext`col],
        Attributes[Subscript] = {NHoldRest}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "b10c4270-1794-4107-b479-0c37daacc5c2"],

Cell[TextData[{
 "References\n[1] Baumann, Rachael L; ",
 StyleBox["Method of Joints to Solve a Truss Problem",
  FontSlant->"Italic"],
 ", Retrieved from: \
http://demonstrations.wolfram.com/MethodOfJointsToSolveATrussProblem/"
}], "DetailNotes",
 CellID->162602332,
 ExpressionUUID -> "b48eff21-e272-4d1c-9995-4d26c60e65a1"]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 369, 10, 182, "Title"],
Cell[1858, 47, 2224, 40, 204, "Text"],
Cell[4085, 89, 46592, 1010, 657, "Output"],
Cell[50680, 1101, 326, 8, 39, "DetailNotes",
 CellID->162602332]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Dxph8KbEcE7Q#DKTaF0uHww2 *)
